# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillAuditGroupChild(Model):
    """BillAuditGroupChild.

    :param audit_group_id:
    :type audit_group_id: int
    :param audit_group_code:
    :type audit_group_code: str
    :param audit_group_info:
    :type audit_group_info: str
    :param description:
    :type description: str
    """

    _attribute_map = {
        'audit_group_id': {'key': 'auditGroupId', 'type': 'int'},
        'audit_group_code': {'key': 'auditGroupCode', 'type': 'str'},
        'audit_group_info': {'key': 'auditGroupInfo', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
    }

    def __init__(self, audit_group_id=None, audit_group_code=None, audit_group_info=None, description=None):
        super(BillAuditGroupChild, self).__init__()
        self.audit_group_id = audit_group_id
        self.audit_group_code = audit_group_code
        self.audit_group_info = audit_group_info
        self.description = description
