# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeRequest(Model):
    """MeRequest.

    :param preference:
    :type preference: ~energycap.sdk.models.Preference
    """

    _attribute_map = {
        'preference': {'key': 'preference', 'type': 'Preference'},
    }

    def __init__(self, preference=None):
        super(MeRequest, self).__init__()
        self.preference = preference
