# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GLSubCodeChildRequest(Model):
    """GLSubCodeChildRequest.

    :param sub_code_index: Index of this sub code (1-20) <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 1 and 20</span>
    :type sub_code_index: int
    :param value: Value for the sub code <span class='property-internal'>Must
     be between 0 and 25 characters</span>
    :type value: str
    """

    _validation = {
        'sub_code_index': {'required': True, 'maximum': 20, 'minimum': 1},
        'value': {'max_length': 25, 'min_length': 0},
    }

    _attribute_map = {
        'sub_code_index': {'key': 'subCodeIndex', 'type': 'int'},
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, sub_code_index, value=None):
        super(GLSubCodeChildRequest, self).__init__()
        self.sub_code_index = sub_code_index
        self.value = value
