# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestNormalizedYearlyResponseCommodityResults(Model):
    """PlaceDigestNormalizedYearlyResponseCommodityResults.

    :param year: year
    :type year: str
    :param common_use: Common Use
    :type common_use: float
    :param global_use: Global Use
    :type global_use: float
    """

    _attribute_map = {
        'year': {'key': 'year', 'type': 'str'},
        'common_use': {'key': 'commonUse', 'type': 'float'},
        'global_use': {'key': 'globalUse', 'type': 'float'},
    }

    def __init__(self, year=None, common_use=None, global_use=None):
        super(PlaceDigestNormalizedYearlyResponseCommodityResults, self).__init__()
        self.year = year
        self.common_use = common_use
        self.global_use = global_use
