# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpecificAuditPropertyChild(Model):
    """SpecificAuditPropertyChild.

    :param property_id: The Id of the property <span
     class='property-internal'>Required</span>
    :type property_id: int
    :param value: The value for the property <span
     class='property-internal'>Required</span>
    :type value: str
    """

    _validation = {
        'property_id': {'required': True},
        'value': {'required': True},
    }

    _attribute_map = {
        'property_id': {'key': 'propertyId', 'type': 'int'},
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, property_id, value):
        super(SpecificAuditPropertyChild, self).__init__()
        self.property_id = property_id
        self.value = value
