# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AuditCategory(Model):
    """AuditCategory.

    :param audit_category_id:
    :type audit_category_id: int
    :param audit_category_code:
    :type audit_category_code: str
    :param audit_category_info:
    :type audit_category_info: str
    """

    _attribute_map = {
        'audit_category_id': {'key': 'auditCategoryId', 'type': 'int'},
        'audit_category_code': {'key': 'auditCategoryCode', 'type': 'str'},
        'audit_category_info': {'key': 'auditCategoryInfo', 'type': 'str'},
    }

    def __init__(self, audit_category_id=None, audit_category_code=None, audit_category_info=None):
        super(AuditCategory, self).__init__()
        self.audit_category_id = audit_category_id
        self.audit_category_code = audit_category_code
        self.audit_category_info = audit_category_info
