# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupDisplaySetting(Model):
    """GroupDisplaySetting.

    :param period_type:
    :type period_type: int
    :param data_view:
    :type data_view: str
    :param commodity_id:
    :type commodity_id: int
    :param show_excluded_members:
    :type show_excluded_members: bool
    :param show_zero_averages:
    :type show_zero_averages: bool
    """

    _attribute_map = {
        'period_type': {'key': 'periodType', 'type': 'int'},
        'data_view': {'key': 'dataView', 'type': 'str'},
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'show_excluded_members': {'key': 'showExcludedMembers', 'type': 'bool'},
        'show_zero_averages': {'key': 'showZeroAverages', 'type': 'bool'},
    }

    def __init__(self, period_type=None, data_view=None, commodity_id=None, show_excluded_members=None, show_zero_averages=None):
        super(GroupDisplaySetting, self).__init__()
        self.period_type = period_type
        self.data_view = data_view
        self.commodity_id = commodity_id
        self.show_excluded_members = show_excluded_members
        self.show_zero_averages = show_zero_averages
