# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceEnergyStarPlaceTypeCreate(Model):
    """PlaceEnergyStarPlaceTypeCreate.

    :param energy_star_place_type_id: The energystar placetype identifier
    :type energy_star_place_type_id: int
    :param energy_star_place_properties: The energystar place properties
     object
    :type energy_star_place_properties:
     list[~energycap.sdk.models.EnergyStarPlacePropertyCreate]
    """

    _attribute_map = {
        'energy_star_place_type_id': {'key': 'energyStarPlaceTypeId', 'type': 'int'},
        'energy_star_place_properties': {'key': 'energyStarPlaceProperties', 'type': '[EnergyStarPlacePropertyCreate]'},
    }

    def __init__(self, energy_star_place_type_id=None, energy_star_place_properties=None):
        super(PlaceEnergyStarPlaceTypeCreate, self).__init__()
        self.energy_star_place_type_id = energy_star_place_type_id
        self.energy_star_place_properties = energy_star_place_properties
