# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculatedBillDemandResponse(Model):
    """CalculatedBillDemandResponse.

    :param readings_from_channel: Use channel data readings to calculate bill
     demand
    :type readings_from_channel:
     ~energycap.sdk.models.ChannelChildWithObservationType
    :param fixed_demand: Use a fixed amount for calculate bill demand
    :type fixed_demand: ~energycap.sdk.models.FixedAmountResponse
    """

    _attribute_map = {
        'readings_from_channel': {'key': 'readingsFromChannel', 'type': 'ChannelChildWithObservationType'},
        'fixed_demand': {'key': 'fixedDemand', 'type': 'FixedAmountResponse'},
    }

    def __init__(self, readings_from_channel=None, fixed_demand=None):
        super(CalculatedBillDemandResponse, self).__init__()
        self.readings_from_channel = readings_from_channel
        self.fixed_demand = fixed_demand
