# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillActionHeaderUpdate(Model):
    """BillActionHeaderUpdate.

    :param bill_ids: Bill IDs whose headers are going to be updated <span
     class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>Required</span>
    :type bill_ids: list[int]
    :param bill_header: Bill header values to update <span
     class='property-internal'>Required</span>
    :type bill_header: ~energycap.sdk.models.BillHeaderUpdate
    """

    _validation = {
        'bill_ids': {'required': True},
        'bill_header': {'required': True},
    }

    _attribute_map = {
        'bill_ids': {'key': 'billIds', 'type': '[int]'},
        'bill_header': {'key': 'billHeader', 'type': 'BillHeaderUpdate'},
    }

    def __init__(self, bill_ids, bill_header):
        super(BillActionHeaderUpdate, self).__init__()
        self.bill_ids = bill_ids
        self.bill_header = bill_header
