# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WidgetResponse(Model):
    """WidgetResponse.

    :param widget_id: Widget identifier
    :type widget_id: int
    :param widget_info: Widget info
    :type widget_info: str
    :param description: Widget description
    :type description: str
    :param tags: Widget tags
    :type tags: list[str]
    :param filters: Widget filters
    :type filters: list[~energycap.sdk.models.FilterResponse]
    """

    _attribute_map = {
        'widget_id': {'key': 'widgetId', 'type': 'int'},
        'widget_info': {'key': 'widgetInfo', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'tags': {'key': 'tags', 'type': '[str]'},
        'filters': {'key': 'filters', 'type': '[FilterResponse]'},
    }

    def __init__(self, widget_id=None, widget_info=None, description=None, tags=None, filters=None):
        super(WidgetResponse, self).__init__()
        self.widget_id = widget_id
        self.widget_info = widget_info
        self.description = description
        self.tags = tags
        self.filters = filters
