# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillViewAccountChild(Model):
    """BillViewAccountChild.

    :param account_id:
    :type account_id: int
    :param account_code:
    :type account_code: str
    :param account_info:
    :type account_info: str
    :param account_type:
    :type account_type: ~energycap.sdk.models.AccountTypeChild
    :param address:
    :type address: ~energycap.sdk.models.BillViewAddressChild
    :param vendor:
    :type vendor: ~energycap.sdk.models.BillViewVendorChild
    :param general_ledger:
    :type general_ledger: ~energycap.sdk.models.GeneralLedgerChild
    """

    _attribute_map = {
        'account_id': {'key': 'accountId', 'type': 'int'},
        'account_code': {'key': 'accountCode', 'type': 'str'},
        'account_info': {'key': 'accountInfo', 'type': 'str'},
        'account_type': {'key': 'accountType', 'type': 'AccountTypeChild'},
        'address': {'key': 'address', 'type': 'BillViewAddressChild'},
        'vendor': {'key': 'vendor', 'type': 'BillViewVendorChild'},
        'general_ledger': {'key': 'generalLedger', 'type': 'GeneralLedgerChild'},
    }

    def __init__(self, account_id=None, account_code=None, account_info=None, account_type=None, address=None, vendor=None, general_ledger=None):
        super(BillViewAccountChild, self).__init__()
        self.account_id = account_id
        self.account_code = account_code
        self.account_info = account_info
        self.account_type = account_type
        self.address = address
        self.vendor = vendor
        self.general_ledger = general_ledger
