# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillHeaderUpdateResponse(Model):
    """BillHeaderUpdateResponse.

    :param bill_update_statuses:
    :type bill_update_statuses:
     list[~energycap.sdk.models.BillHeaderUpdateResponseChild]
    :param selected:
    :type selected: int
    :param updated:
    :type updated: int
    """

    _attribute_map = {
        'bill_update_statuses': {'key': 'billUpdateStatuses', 'type': '[BillHeaderUpdateResponseChild]'},
        'selected': {'key': 'selected', 'type': 'int'},
        'updated': {'key': 'updated', 'type': 'int'},
    }

    def __init__(self, bill_update_statuses=None, selected=None, updated=None):
        super(BillHeaderUpdateResponse, self).__init__()
        self.bill_update_statuses = bill_update_statuses
        self.selected = selected
        self.updated = updated
