# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReadingsObservation(Model):
    """ReadingsObservation.

    :param observation_id: The unique ID for the reading
    :type observation_id: long
    :param time: The date and time of the reading
    :type time: datetime
    :param value: The raw or computed value of the reading
    :type value: float
    :param raw_value: The raw value of the reading (before multiplier or delta
     are applied)
    :type raw_value: float
    :param estimated: Indicates if the reading is estimated
    :type estimated: bool
    :param note: A note pertaining to the reading
    :type note: str
    """

    _attribute_map = {
        'observation_id': {'key': 'observationId', 'type': 'long'},
        'time': {'key': 'time', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'float'},
        'raw_value': {'key': 'rawValue', 'type': 'float'},
        'estimated': {'key': 'estimated', 'type': 'bool'},
        'note': {'key': 'note', 'type': 'str'},
    }

    def __init__(self, observation_id=None, time=None, value=None, raw_value=None, estimated=None, note=None):
        super(ReadingsObservation, self).__init__()
        self.observation_id = observation_id
        self.time = time
        self.value = value
        self.raw_value = raw_value
        self.estimated = estimated
        self.note = note
