# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReadingImportRequest(Model):
    """ReadingImportRequest.

    :param profile_code: A reading import data profile code.
    :type profile_code: str
    :param inline_profile: A reading import data profile definition.
    :type inline_profile: ~energycap.sdk.models.ReadingImportProfile
    :param data: The base64 encoded file. <span
     class='property-internal'>Required</span>
    :type data: str
    :param auto_create_channels: Create new channels if they don't exist?
    :type auto_create_channels: bool
    :param import_note: Optional note/comment.
    :type import_note: str
    """

    _validation = {
        'data': {'required': True},
    }

    _attribute_map = {
        'profile_code': {'key': 'profileCode', 'type': 'str'},
        'inline_profile': {'key': 'inlineProfile', 'type': 'ReadingImportProfile'},
        'data': {'key': 'data', 'type': 'str'},
        'auto_create_channels': {'key': 'autoCreateChannels', 'type': 'bool'},
        'import_note': {'key': 'importNote', 'type': 'str'},
    }

    def __init__(self, data, profile_code=None, inline_profile=None, auto_create_channels=None, import_note=None):
        super(ReadingImportRequest, self).__init__()
        self.profile_code = profile_code
        self.inline_profile = inline_profile
        self.data = data
        self.auto_create_channels = auto_create_channels
        self.import_note = import_note
