# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillTemplateUnitMismatchResponse(Model):
    """BillTemplateUnitMismatchResponse.

    :param account_meter_id:
    :type account_meter_id: int
    :param meter:
    :type meter: ~energycap.sdk.models.UnitSystemMeterChild
    :param account:
    :type account: ~energycap.sdk.models.AccountChild
    :param template:
    :type template: ~energycap.sdk.models.UnitSystemTemplateChild
    :param meter_commodity_mismatches:
    :type meter_commodity_mismatches:
     list[~energycap.sdk.models.CommodityMismatchChild]
    :param bill_commodity_mismatches:
    :type bill_commodity_mismatches:
     list[~energycap.sdk.models.CommodityMismatchChild]
    :param use_mismatches:
    :type use_mismatches: list[~energycap.sdk.models.UnitMismatchChild]
    :param actual_demand_mismatches:
    :type actual_demand_mismatches:
     list[~energycap.sdk.models.UnitMismatchChild]
    :param billed_demand_mismatches:
    :type billed_demand_mismatches:
     list[~energycap.sdk.models.UnitMismatchChild]
    """

    _attribute_map = {
        'account_meter_id': {'key': 'accountMeterId', 'type': 'int'},
        'meter': {'key': 'meter', 'type': 'UnitSystemMeterChild'},
        'account': {'key': 'account', 'type': 'AccountChild'},
        'template': {'key': 'template', 'type': 'UnitSystemTemplateChild'},
        'meter_commodity_mismatches': {'key': 'meterCommodityMismatches', 'type': '[CommodityMismatchChild]'},
        'bill_commodity_mismatches': {'key': 'billCommodityMismatches', 'type': '[CommodityMismatchChild]'},
        'use_mismatches': {'key': 'useMismatches', 'type': '[UnitMismatchChild]'},
        'actual_demand_mismatches': {'key': 'actualDemandMismatches', 'type': '[UnitMismatchChild]'},
        'billed_demand_mismatches': {'key': 'billedDemandMismatches', 'type': '[UnitMismatchChild]'},
    }

    def __init__(self, account_meter_id=None, meter=None, account=None, template=None, meter_commodity_mismatches=None, bill_commodity_mismatches=None, use_mismatches=None, actual_demand_mismatches=None, billed_demand_mismatches=None):
        super(BillTemplateUnitMismatchResponse, self).__init__()
        self.account_meter_id = account_meter_id
        self.meter = meter
        self.account = account
        self.template = template
        self.meter_commodity_mismatches = meter_commodity_mismatches
        self.bill_commodity_mismatches = bill_commodity_mismatches
        self.use_mismatches = use_mismatches
        self.actual_demand_mismatches = actual_demand_mismatches
        self.billed_demand_mismatches = billed_demand_mismatches
