# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SystemUserRoleChild(Model):
    """SystemUserRoleChild.

    :param user_role_id: The user role identifier
    :type user_role_id: int
    :param user_role_info: The user role name
    :type user_role_info: str
    """

    _attribute_map = {
        'user_role_id': {'key': 'userRoleId', 'type': 'int'},
        'user_role_info': {'key': 'userRoleInfo', 'type': 'str'},
    }

    def __init__(self, user_role_id=None, user_role_info=None):
        super(SystemUserRoleChild, self).__init__()
        self.user_role_id = user_role_id
        self.user_role_info = user_role_info
