# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceCost(Model):
    """PlaceCost.

    :param place: Place
    :type place: ~energycap.sdk.models.PlaceChild
    :param total_cost: Total cost
    :type total_cost: float
    :param current_area: Current Area
    :type current_area: int
    :param current_area_unit: Current Area Units
    :type current_area_unit: str
    :param area_unit: Area Units
    :type area_unit: str
    :param cost_per_area: Cost per area
    :type cost_per_area: float
    :param cost_unit: The cost unit of measure
    :type cost_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'place': {'key': 'place', 'type': 'PlaceChild'},
        'total_cost': {'key': 'totalCost', 'type': 'float'},
        'current_area': {'key': 'currentArea', 'type': 'int'},
        'current_area_unit': {'key': 'currentAreaUnit', 'type': 'str'},
        'area_unit': {'key': 'areaUnit', 'type': 'str'},
        'cost_per_area': {'key': 'costPerArea', 'type': 'float'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
    }

    def __init__(self, place=None, total_cost=None, current_area=None, current_area_unit=None, area_unit=None, cost_per_area=None, cost_unit=None):
        super(PlaceCost, self).__init__()
        self.place = place
        self.total_cost = total_cost
        self.current_area = current_area
        self.current_area_unit = current_area_unit
        self.area_unit = area_unit
        self.cost_per_area = cost_per_area
        self.cost_unit = cost_unit
