# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculatedBillDemandRequest(Model):
    """<span class='property-internal'>Only one of ReadingsChannelId, FixedDemand
    is required</span>.

    :param readings_channel_id: Use channel data readings to calculate bill
     demand
    :type readings_channel_id: int
    :param fixed_demand: Use a fixed amount of a given unit for bill demand
    :type fixed_demand: ~energycap.sdk.models.FixedDemandRequest
    """

    _attribute_map = {
        'readings_channel_id': {'key': 'readingsChannelId', 'type': 'int'},
        'fixed_demand': {'key': 'fixedDemand', 'type': 'FixedDemandRequest'},
    }

    def __init__(self, readings_channel_id=None, fixed_demand=None):
        super(CalculatedBillDemandRequest, self).__init__()
        self.readings_channel_id = readings_channel_id
        self.fixed_demand = fixed_demand
